==> dravid-0.13.1-py3-none-any.whl: drd/prompts/error_resolution_prompt.py <==
# File: prompts/error_resolution_prompts.py

def get_error_resolution_prompt(previous_context, cmd, error_type, error_message, error_trace, project_context):
    return f"""
# Error Context
Previous context: {previous_context}

An error occurred while executing the following command:
{cmd['type']}: {cmd.get('command') or cmd.get('filename')}

Error type: {error_type}
Error message: {error_message}

Error trace:
{error_trace}

Project context:
{project_context}

# Instructions for dravid: Error Resolution Assistant
Analyze the error above and provide steps to fix it. 
This is being run in a monitoring thread, so don't suggest server starting commands like npm run dev.
Make sure you don't try for drastic changes, just the needed and precise fix. 
You have to identify the root cause, and your proposed solution and make it part of the explanation tag
and the actual code modifications or commands to run include it in the steps part.
Your response should be in strictly XML format with no other extra messages. Use the following format:
<response>
<explanation>Explanation: analysis in a brief sentence, root cause in bullet points, proposed solution in bullet points </explanation>
<requires_restart>true/false</requires_restart>
<steps>
    <step>
    <type>shell</type>
    <command>command to execute</command>
    </step>
    <step>
    <type>file</type>
    <operation>CREATE</operation>
    <filename>path/to/file.ext</filename>
    <content>
        <![CDATA[
          def example():
           re...
        ]]>
    </content>
    </step>
    <step>
    <type>file</type>
    <operation>UPDATE</operation>
    <filename>path/to/existing/file.ext</filename>
    <content>
        <![CDATA[
          Specify changes using the following format:
          + line_number: content to add
          - line_number: (to remove the line)
          r line_number: content to replace the line with
          
          Example:
          + 3: import new_module
          - 10:
          r 15: def updated_function():
        ]]>
    </content>
    </step>
    <step>
    <type>file</type>
    <operation>DELETE</operation>
    <filename>path/to/file/to/delete.ext</filename>
    </step>
</steps>
</response>

Important guidelines:
1. Use relative paths for all file operations and commands.
2. Do not use 'cd' commands. 
3. Strictly generate XML only, no other extra words.
4 For file updates, provide ONLY the specific changes to be made, not the entire file content.
  - If you need to update a specific part of a file, first fetch the current content, if not dont suggest UPDATE 
  - Provide precise line-by-line modifications per the given format.
  - Ensure that the changes are accurate, specifying the correct line numbers for additions, removals, 
5. Try to avoid sudo approach as much but as a last resort.  Give OS & arch specific information whenever needed.
6. If a file is created or updated, include a step to update the file metadata in the project metadata.
7. If there is a need to create a .png or .jpg files with no content, you can prefix the filename with "placeholder-"
8. Create reusable functions or components as much as possible in separate files so to avoid large lined files.
10. If you see an opportunity to reuse a code by importing from some existing modules based on project context, please do.
11. Strive to create less 120 lines of code in a file, feel free to split and create new files to reference. This makes it
easy for coding assistants to load only needed context
12. Since you will be run as a program things like `source ~/.zshrc` script won't work, so after you suggest 
an export like 
 echo 'export PATH="/usr/local/opt/maven/bin:$PATH"' >> ~/.zshrc
don't try to suggest the command: `source ~/.zshrc`, instead suggest a shell command to export that env in the current terminal
like
export PATH="/usr/local/opt/maven/bin:$PATH
13. Do not attempt to delete any files outside the current directory like ~/.zshrc or others. 
14. Never run destructive commands like `rm -rf`.  unless and until it is necessary
15. When installing new languages try to install through a version manager
For eg, if you need to install python, use something like pyenv and related lib.
16. When it is a shell command avoid using && instead suggest as a separate step as it has to be executed sequentially
 for eg: `echo 'hello' && echo 'print'` should be avoided and it has to be two different steps instead
17. For any of the tags if there is no relevant content you can use None for eg: <start_command>None</start_command>
18: Include a <requires_restart> tag with a value of "true" or "false" to indicate whether the fix requires a server restart. Consider the following guidelines:
    - If the fix involves changes to configuration files, environment variables, or package installations, a restart is likely needed.
    - If the fix is a simple code change that doesn't affect the server's core functionality or loaded modules, a restart may not be necessary.
    - When in doubt, err on the side of caution and suggest a restart.
19. If there are any dependent files that is not there in project_context and you're creating a file, ensure you create
the dependent file also. Eg, when creating a sample.html and having a dependent sample.css, you need to create both.
"""

==> dravid-0.13.6-py3-none-any.whl: drd/prompts/error_resolution_prompt.py <==
# File: prompts/error_resolution_prompts.py

def get_error_resolution_prompt(previous_context, cmd, error_type, error_message, error_trace, project_context):
    return f"""
# Error Context
Previous context: {previous_context}

An error occurred while executing the following command:
{cmd['type']}: {cmd.get('command') or cmd.get('filename')}

Error type: {error_type}
Error message: {error_message}

Error trace:
{error_trace}

Project context:
{project_context}

# Instructions for dravid: Error Resolution Assistant
Analyze the error above and provide steps to fix it. 
This is being run in a monitoring thread, so don't suggest server starting commands like npm run dev.
Make sure you don't try for drastic changes, just the needed and precise fix. 
You have to identify the root cause, and your proposed solution and make it part of the explanation tag
and the actual code modifications or commands to run include it in the steps part.
Your response should be in strictly XML format with no other extra messages. Use the following format:
<response>
<explanation>Explanation: analysis in a brief sentence, root cause in bullet points, proposed solution in bullet points </explanation>
<requires_restart>true/false</requires_restart>
<steps>
    <step>
    <type>shell</type>
    <command>command to execute</command>
    </step>
    <step>
    <type>file</type>
    <operation>CREATE</operation>
    <filename>path/to/file.ext</filename>
    <content>
        <![CDATA[
          def example():
           re...
        ]]>
    </content>
    </step>
    <step>
    <type>file</type>
    <operation>UPDATE</operation>
    <filename>path/to/existing/file.ext</filename>
    <content>
        <![CDATA[
          Specify changes using the following format:
          + line_number: content to add
          - line_number: (to remove the line)
          r line_number: content to replace the line with
          
          Example:
          + 3:import json
          - 10:
          r 15:   if a == 1
          + 24:         break
        ]]>
    </content>
    </step>
    <step>
    <type>file</type>
    <operation>DELETE</operation>
    <filename>path/to/file/to/delete.ext</filename>
    </step>
</steps>
</response>

Important guidelines:
1. Use relative paths for all file operations and commands.
2. Do not use 'cd' commands. 
3. Strictly generate XML only, no other extra words.
4 For file updates, provide ONLY the specific changes to be made, not the entire file content.
  - If you need to update a specific part of a file, first fetch the current content, if not dont suggest UPDATE 
  - Provide precise line-by-line modifications per the given format including indentations (important)
  - Ensure that the changes are accurate, specifying the correct line numbers for additions, removals, 
5. Try to avoid sudo approach as much but as a last resort.  Give OS & arch specific information whenever needed.
6. If a file is created or updated, include a step to update the file metadata in the project metadata.
7. If there is a need to create a .png or .jpg files with no content, you can prefix the filename with "placeholder-"
8. Create reusable functions or components as much as possible in separate files so to avoid large lined files.
10. If you see an opportunity to reuse a code by importing from some existing modules based on project context, please do.
11. Strive to create less 120 lines of code in a file, feel free to split and create new files to reference. This makes it
easy for coding assistants to load only needed context
12. Since you will be run as a program things like `source ~/.zshrc` script won't work, so after you suggest 
an export like 
 echo 'export PATH="/usr/local/opt/maven/bin:$PATH"' >> ~/.zshrc
don't try to suggest the command: `source ~/.zshrc`, instead suggest a shell command to export that env in the current terminal
like
export PATH="/usr/local/opt/maven/bin:$PATH
13. Do not attempt to delete any files outside the current directory like ~/.zshrc or others. 
14. Never run destructive commands like `rm -rf`.  unless and until it is necessary
15. When installing new languages try to install through a version manager
For eg, if you need to install python, use something like pyenv and related lib.
16. When it is a shell command avoid using && instead suggest as a separate step as it has to be executed sequentially
 for eg: `echo 'hello' && echo 'print'` should be avoided and it has to be two different steps instead
17. For any of the tags if there is no relevant content you can use None for eg: <start_command>None</start_command>
18: Include a <requires_restart> tag with a value of "true" or "false" to indicate whether the fix requires a server restart. Consider the following guidelines:
    - If the fix involves changes to configuration files, environment variables, or package installations, a restart is likely needed.
    - If the fix is a simple code change that doesn't affect the server's core functionality or loaded modules, a restart may not be necessary.
    - When in doubt, err on the side of caution and suggest a restart.
19. If there are any dependent files that is not there in project_context and you're creating a file, ensure you create
the dependent file also. Eg, when creating a sample.html and having a dependent sample.css, you need to create both.
"""
